@@ -1,5 +1,3 @@
-context("Reorder within")
-
 suppressPackageStartupMessages(library(ggplot2))
 
 test_that("Can reorder within", {
@@ -7,7 +5,7 @@ test_that("Can reorder within", {
                                      mtcars$mpg,
                                      mtcars$vs)
 
-  expect_is(mtcars_reordered, "factor")
+  expect_s3_class(mtcars_reordered, "factor")
   expect_equal(length(levels(mtcars_reordered)), 5)
 })
 
@@ -16,7 +14,7 @@ test_that("Can reorder within multiple variables", {
                                      mtcars$mpg,
                                      list(mtcars$vs, mtcars$am))
 
-  expect_is(mtcars_reordered, "factor")
+  expect_s3_class(mtcars_reordered, "factor")
   expect_equal(length(levels(mtcars_reordered)), 7)
 })
 
@@ -26,16 +24,34 @@ test_that("Can make a plot", {
     scale_x_reordered() +
     facet_wrap(~ cyl, scales = "free_x")
 
-  expect_is(p, "ggplot")
+  expect_s3_class(p, "ggplot")
   vdiffr::expect_doppelganger("reordered boxplot", p)
 
 })
 
+test_that("Can make a plot with custom labels", {
+
+  custom_labeler <- function(x) {
+    x %>%
+      stringr::str_replace("___[0-9]+$", "") %>%
+      stringr::str_replace("0", "ZERO")
+  }
+
+  p <- ggplot(mtcars, aes(reorder_within(vs, mpg, cyl), mpg)) +
+    geom_boxplot() +
+    scale_x_reordered(labels = custom_labeler) +
+    facet_wrap(~ cyl, scales = "free_x")
+
+  expect_s3_class(p, "ggplot")
+  vdiffr::expect_doppelganger("custom label boxplot", p)
+
+})
+
 test_that("Can make a multi-facet plot", {
 
-  expect_doppelganger <- function(title, fig, path = NULL, ...) {
+  expect_doppelganger <- function(title, fig, ...) {
     testthat::skip_if_not_installed("vdiffr")
-    vdiffr::expect_doppelganger(title, fig, path = path, ...)
+    vdiffr::expect_doppelganger(title, fig, ...)
   }
 
   p <- ggplot(mtcars, aes(reorder_within(carb, mpg, list(vs, am)), mpg)) +
@@ -43,7 +59,7 @@ test_that("Can make a multi-facet plot", {
     scale_x_reordered() +
     facet_wrap(vs ~ am, scales = "free_x")
 
-  expect_is(p, "ggplot")
+  expect_s3_class(p, "ggplot")
   expect_doppelganger("reordered multi-facet boxplot", p)
 })
 
